@@ -154,7 +154,7 @@ set_plotting_fun <- function(x, plotfun = NULL) {
     STOP_sampling_only(funname)
   fun <- try(getExportedValue("rstan", funname), silent = TRUE)
   if (inherits(fun, "try-error")) 
-    stop("Plotting function not found. See ?rstanarm::plots for valid names.", 
+    stop("Plotting function not found. See help('rstanarm-plots') for valid names.", 
          call. = FALSE)
   
   return(fun)
@@ -204,6 +204,17 @@ pairs.stanreg <- function(x, ...) {
     STOP_sampling_only("pairs")
   requireNamespace("rstan")
   requireNamespace("KernSmooth")
+  
+  if (is.mer(x)) {
+    dots <- list(...)
+    if (is.null(dots[["pars"]]))
+      return(pairs(x$stanfit, pars = names(fixef(x)), ...))
+    
+    b <- b_names(rownames(x$stan_summary), value = TRUE)
+    if (any(dots[["pars"]] %in% b))
+      stop("pairs.stanreg does not yet allow group-level parameters in 'pars'.")
+  }
+  
   pairs(x$stanfit, ...)
 }
 
