@@ -52,6 +52,7 @@ stan_polr.fit <- function(x, y, wt = NULL, offset = NULL,
   X <- Q
   colnames(X) <- cn
   xbar <- c(xbar %*% R_inv)
+  if (length(xbar) == 1) dim(xbar) <- 1L
   
   has_weights <- isTRUE(length(wt) > 0 && !all(wt == 1))
   if (!has_weights) 
@@ -97,13 +98,17 @@ stan_polr.fit <- function(x, y, wt = NULL, offset = NULL,
     
   N <- nrow(X)
   K <- ncol(X)
+  X <- array(X, dim = c(1L, N, K))
   standata <- nlist(J, N, K, X, xbar, y, prior_PD, link, 
                     has_weights, weights, has_offset, offset,
                     prior_dist, regularization, prior_counts,
                     is_skewed, shape, rate,
                     # the rest of these are not actually used
                     has_intercept = 0L, prior_dist_for_intercept = 0L, 
-                    family = 1L)
+                    family = 1L,
+                    dense_X = TRUE, # sparse is not a viable option
+                    nnz_X = 0L, w_X = double(0), v_X = integer(0), u_X = integer(0)
+  )
   stanfit <- stanmodels$polr
   if (J > 2) {
     pars <- c("beta", "zeta", "mean_PPD")
@@ -127,9 +132,11 @@ stan_polr.fit <- function(x, y, wt = NULL, offset = NULL,
   
   thetas <- extract(stanfit, pars = "beta", inc_warmup = TRUE, permuted = FALSE)
   betas <- apply(thetas, 1:2, FUN = function(theta) R_inv %*% theta)
-  for (chain in 1:tail(dim(betas), 1)) for (param in 1:nrow(betas)) {
-    stanfit@sim$samples[[chain]][[(J == 2) + param]] <- 
-      if (ncol(X) > 1) betas[param, , chain] else betas[param, chain]
+  if (K == 1) for (chain in 1:tail(dim(betas), 1)) {
+    stanfit@sim$samples[[chain]][[(J == 2) + 1L]] <- betas[,chain]
+  }
+  else for (chain in 1:tail(dim(betas), 1)) for (param in 1:nrow(betas)) {
+    stanfit@sim$samples[[chain]][[(J == 2) + param]] <- betas[param, , chain]
   }
   
   if (J > 2) {
